@@ -191,11 +191,11 @@ class Naive(object):
         else:
             t = lag + 1
             t_lag = t - lag
-            y = self.y
+            y = self.y.to_numpy()
             end = len(y) - lag
-            yt = y[t:].to_numpy()
-            yt_lag = y[t_lag:end].to_numpy()
-            y_last = self.y[len(y) - 1]
+            yt = y[t:]
+            yt_lag = y[t_lag:end]
+            y_last = y.take(-1)
             mod = sm.GLM(yt, yt_lag, family=sm.families.Gaussian())
             sigma = np.sqrt(mod.fit().scale)
             rng = np.random.default_rng()
@@ -380,25 +380,18 @@ class Snaive(object):
             df_pred = pd.DataFrame(np_predictions, columns=["y_sim"])
             df_result = pd.concat([df_cross, df_pred], axis=1)
         else:
-            t = lag + 1
-            t_lag = t - lag
-            y = self.y
-            end = len(y) - lag
-            yt = y[t:].to_numpy()
-            yt_lag = y[t_lag:end].to_numpy()
+            y = self.y.to_numpy()
+            last_start = len(y) - lag
+            last_end = len(y)
+            yt = y[lag:last_end]
+            yt_lag = y[0:last_start]
             # y_last = self.y[(len(y)-1)-(lag-(horizon%lag))]
             mod = sm.GLM(yt, yt_lag, family=sm.families.Gaussian())
             sigma = np.sqrt(mod.fit().scale)
             rng = np.random.default_rng()
             forecast = np.empty([uncertainty_samples, horizon])
             for h in range(0, horizon):
-                forecast[:, h] = self.y[
-                    (len(y)) - (lag - ((h) % lag))
-                ] + sigma * np.sqrt(
-                    np.trunc(((h) * 1) / (lag)) + 1
-                ) * rng.standard_normal(
-                    uncertainty_samples
-                )
+                forecast[:, h] = y[(len(y)) - (lag - ((h) % lag))] + sigma * np.sqrt(np.trunc(((h) * 1) / (lag)) + 1) * rng.standard_normal(uncertainty_samples)
             np_predictions = forecast.transpose().reshape(
                 uncertainty_samples * horizon, 1
             )
